import React from 'react';
import PropTypes from 'prop-types';
import { forwardRef } from 'react';
import { Link } from 'gatsby';
import { motion } from 'framer-motion';
import { Box } from '@thepuzzlers/pieces';

// Set styling for active Link as follows
// in links.js (in theme)

// hyperlink : {
//   ... general styling here
//   '&.active' : {
//     ... styling for active Link here
//   }
// }
// or: pass them throug the activeStyle prop (which does not accept theme ui specific keys)

// This componenet is Gatsby specific!
export const GatsbyLink = forwardRef(
  (
    {
      active,
      to,
      children,
      variant,
      sx: { padding, p, ...sx },

      // Gatsby Link specific props
      activeStyle,
      activeClassName,
      partiallyActive,
      getProps,
      state,

      ...props
    },
    ref
  ) => (
    <Box
      __themeKey="links"
      as={motion.span}
      className={active ? 'active' : ''}
      ref={ref}
      sx={sx}
      variant={variant}
      {...props}>
      <Link
        activeClassName={activeClassName}
        activeStyle={activeStyle}
        partiallyActive={partiallyActive}
        getProps={getProps}
        state={state}
        style={{
          textDecoration: 'inherit',
          color: 'inherit',
          // We need to apply padding to link itself, to enlarge the clickable area
          padding: padding || p
        }}
        to={to}>
        {children}
      </Link>
    </Box>
  )
);

GatsbyLink.displayName = 'GatsbyLink';

GatsbyLink.propTypes = {
  active: PropTypes.boolean,
  // Gatsby Link specific props
  activeClassName: PropTypes.string,
  activeStyle: PropTypes.node,
  children: PropTypes.node.isRequired,
  getProps: PropTypes.func,

  partiallyActive: PropTypes.bool,
  state: PropTypes.shape(),
  sx: PropTypes.shape({
    padding: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    p: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
  }),
  to: PropTypes.string.isRequired,
  variant: PropTypes.string
};

GatsbyLink.defaultProps = {
  active: false,
  variant: 'hyperLink',
  sx: {},
  activeStyle: undefined,
  activeClassName: 'active',
  partiallyActive: undefined,
  getProps: undefined
};
